[![Build Status](https://travis-ci.org/block-cat/autils.svg?branch=master)](https://travis-ci.org/block-cat/autils)
![PyPI](https://img.shields.io/pypi/v/autils)

# Autils

autils 是一个工具类，截至目前包括如下功能：

## 字符串类

* 随机生成指定长度字符串
  
## 数字类

* 禁止浮点数大于4时以科学记数法显示

## 字典类

* 翻转字段的key和value

## 日志类

* 以标准和文件形式的日志输出

## 校验类

* 字典序排序方法
* 微信签名
* CRC校验(CCITT模式、XMODEN模式)

## 系统帮助类

* 获取本地IP地址
* 获取公网IP地址
* 以sudo的方式运行命令
* 文件夹不存在时创建文件夹


# 安装

```python
pip3 install autils
```